==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/a0/a002610ce1fa1f071eca8960fd2883b5.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Loader/EnvVars/ApiEnvVars.php */
class __TwigTemplate_183e3b49ec11cd211f6e8b26b3fd933f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Loader\\EnvVars;

use Symfony\\Component\\HttpFoundation\\ParameterBag;

class ApiEnvVars implements EnvVarsInterface
{
    public static function load(ParameterBag \$config, ParameterBag \$defaultConfig, ParameterBag \$envVars): void
    {
        \$accessTokenLifetime = \$config->get('api_oauth2_access_token_lifetime');
        \$envVars->set('MAUTIC_API_OAUTH2_ACCESS_TOKEN_LIFETIME', is_int(\$accessTokenLifetime) ? \$accessTokenLifetime * 60 : 3600);

        \$refreshTokenLifetime = \$config->get('api_oauth2_refresh_token_lifetime');
        \$envVars->set('MAUTIC_API_OAUTH2_REFRESH_TOKEN_LIFETIME', is_int(\$refreshTokenLifetime) ? \$refreshTokenLifetime * 60 * 60 * 24 : 1_209_600);

        \$apiRateLimitEnabled = 0 === (int) \$config->get('api_rate_limiter_limit') ? false : true;
        \$envVars->set('MAUTIC_API_RATE_LIMIT_ENABLED', \$apiRateLimitEnabled);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Loader/EnvVars/ApiEnvVars.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Loader/EnvVars/ApiEnvVars.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Loader/EnvVars/ApiEnvVars.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/a0/a002610ce1fa1f071eca8960fd2883b5.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Loader/EnvVars/ApiEnvVars.php */
class __TwigTemplate_183e3b49ec11cd211f6e8b26b3fd933f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Loader\\EnvVars;

use Symfony\\Component\\HttpFoundation\\ParameterBag;

class ApiEnvVars implements EnvVarsInterface
{
    public static function load(ParameterBag \$config, ParameterBag \$defaultConfig, ParameterBag \$envVars): void
    {
        \$accessTokenLifetime = \$config->get('api_oauth2_access_token_lifetime');
        \$envVars->set('MAUTIC_API_OAUTH2_ACCESS_TOKEN_LIFETIME', is_int(\$accessTokenLifetime) ? \$accessTokenLifetime * 60 : 3600);

        \$refreshTokenLifetime = \$config->get('api_oauth2_refresh_token_lifetime');
        \$envVars->set('MAUTIC_API_OAUTH2_REFRESH_TOKEN_LIFETIME', is_int(\$refreshTokenLifetime) ? \$refreshTokenLifetime * 60 * 60 * 24 : 1_209_600);

        \$apiRateLimitEnabled = 0 === (int) \$config->get('api_rate_limiter_limit') ? false : true;
        \$envVars->set('MAUTIC_API_RATE_LIMIT_ENABLED', \$apiRateLimitEnabled);
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Loader/EnvVars/ApiEnvVars.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Loader/EnvVars/ApiEnvVars.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Loader/EnvVars/ApiEnvVars.php");
    }
}
